# PyDo-List
A Simple CLI (Command Line Interface) To Do List to keep you on track!

## Installation
Simple Installation (pip3 required)

  ```bash
  ~$ pip3 install pydotask
  ```

## Usage
Type in the terminal ```pydo``` and if you are having trouble, type in -h or help in the program for short documentation
  
## Future Updates
If you want to see what im working on. Please go to the 'update.txt' file.

## Goal
I love working on the terminal and sometimes I wish I can just open regular GUI apps (simple apps of course) in the terminal
and just close it if I dont need it. Of course this is still an amateur project with bad codes but please give me feedbacks
so I can improve.

### NOTE : This is not yet working! Still a work in progress
